global path "C:\Docs2\EFH_CDI\Chile_MaPP_comparison\new_analysis\\\"
cd "$path\"
local G2 = "ysize(5.4) xsize(9.2) imargin(0 0) graphregion(color(white) margin(vsmall))"
local G4 = "ysize(10.8) xsize(9.2) imargin(0 0 0 0) graphregion(color(white) margin(vsmall))"

clear
import excel "$path\Domestic_credit_selected.xls", sheet("Data") firstrow
local yr=1990
foreach x of varlist C-AG {
rename `x' Domestic_credit`yr'
local yr = `yr'+1
}
reshape long Domestic_credit, i(CountryName CountryCode) j(Year)
save "$path\WDI.dta", replace
clear
import excel "$path\Market capitalization_selected.xls", sheet("Data") firstrow
local yr=1990
foreach x of varlist C-AG {
rename `x' Market_capitalization`yr'
local yr = `yr'+1
}
reshape long Market_capitalization, i(CountryName CountryCode) j(Year)
joinby CountryCode Year using "$path\WDI.dta", unmatched(both) update
tab _merge
drop _merge
save "$path\WDI.dta", replace
clear
import excel "$path\GDP per capita PPP 1990 to 2020 selected.xls", sheet("Data") firstrow
local yr=1990
foreach x of varlist C-AG {
rename `x' GDPpcPPP`yr'
local yr = `yr'+1
}
reshape long GDPpcPPP, i(CountryName CountryCode) j(Year)
joinby CountryCode Year using "$path\WDI.dta", unmatched(master) update
tab _merge
drop _merge
drop if Domestic_credit==. & Market_capitalization==. & GDPpcPPP==.
rename CountryCode iso3
save "$path\WDI.dta", replace

use "$path\iMaPP_Y_otherVars.dta", clear
merge m:m ifscode using "$path\CountryType.dta", keepusing(Country_Type)
replace AE=1 if Country_Type==1
gen EM=1 if Country_Type==2
gen LIC=1 if Country_Type==3
replace EM=1 if EMDE==1 & LIC==. 
tab _merge
capture drop _merge
joinby iso3 Year using "$path\WDI.dta", unmatched(both) update
tab _merge
keep if _merge==3
drop _merge

g GDPpcPPP0 = GDPpcPPP if Year==2010
bysort iso3: egen GDPpcPPP2010=mean(GDPpcPPP0)
keep C_* Country CountryName iso3 Year Country_Type AE EM LIC Market_capitalization Domestic_credit GDPpcPPP GDPpcPPP2010
*gen C_Supply_general=C_RR+C_Liquidity+C_LFX
*gen C_Supply_capital=C_LVR+C_CCB+C_Conservation+C_Capital
drop C_Capital_* C_LCG_* C_LoanR_* C_RR_FCD C_CCB-C_OT   //keep if Year==2016|Year==2019
**** Se coloca etiqueta a las variables que son sumas
capture label var C_LDemand_Sum "Loan demand: LTV+DSTI"
capture label var C_LSupply_Sum "Loan supply Sum: LCG+LLP+LoanR+LTD+LFC"
capture label var C_Loan_Sum "Loan Sum: Loan demand + Loan supply Sum"
capture label var C_Supply_Sum "Supply total: Supply general+Supply capital"
capture label var C_Other_Sum "Institutional: Tax+SIFI+OT"
capture label var C_Supply_general "Supply general =RR+Liquidity+LFX"
capture label var C_Supply_capital "Supply of capital: LVR+CCB+Conservation+Capital"
local variables C_SUM_17-C_Supply_capital

replace Country_Type=1 if GDPpcPPP2010>=20000 & GDPpcPPP2010<. & Country_Type==.
replace Country_Type=3 if GDPpcPPP2010<10000 & Country_Type==.
replace Country_Type=3 if Country_Type==.
g lnY = ln(GDPpcPPP)

joinby iso3 Year using "$path\WDI_macro.dta", unmatched(master) update
tab _merge
keep if _merge==3
drop _merge

egen Cid = group(iso3)
xtset Cid Year
reg Market_capitalization C_SUM_17 lnY i.(Country_Type)
reg Domestic_credit C_SUM_17 lnY i.(Country_Type)
local XY "Market_capitalization Domestic_credit lnY C_SUM_17 C_Loan_Sum C_Supply_Sum C_LDemand_Sum C_LSupply_Sum C_Other_Sum C_Supply_capital C_Supply_general"

xtreg Market_capitalization C_SUM_17 lnY, vce(robust)
outreg2 using "$path\tables\Market_capitalization.xls", replace 
xtreg Domestic_credit C_SUM_17 lnY, vce(robust)
outreg2 using "$path\tables\Domestic_credit.xls", replace 
xtreg C_SUM_17 Market_capitalization Domestic_credit lnY, vce(robust)
outreg2 using "$path\tables\iMaPP_DC_MC.xls", replace
foreach x of varlist C_Loan_Sum C_Supply_Sum C_LDemand_Sum C_LSupply_Sum C_Other_Sum C_Supply_capital C_Supply_general { //C_SUM_17
xtreg Market_capitalization `x' lnY, vce(robust)
outreg2 using "$path\tables\Market_capitalization.xls", append
xtreg Domestic_credit `x' lnY, vce(robust)
outreg2 using "$path\tables\Domestic_credit.xls", append
xtreg `x' Market_capitalization Domestic_credit lnY, vce(robust)
outreg2 using "$path\tables\iMaPP_DC_MC.xls", append
}
xtreg Market_capitalization C_SUM_17 lnY RealGDPgr inflation, vce(robust)
outreg2 using "$path\tables\Market_capitalization_vs2.xls", replace 
xtreg Domestic_credit C_SUM_17 lnY RealGDPgr inflation, vce(robust)
outreg2 using "$path\tables\Domestic_credit_vs2.xls", replace 
xtreg C_SUM_17 Market_capitalization Domestic_credit lnY RealGDPgr inflation, vce(robust)
outreg2 using "$path\tables\iMaPP_DC_MC_vs2.xls", replace
foreach x of varlist C_Loan_Sum C_Supply_Sum C_LDemand_Sum C_LSupply_Sum C_Other_Sum C_Supply_capital C_Supply_general { //C_SUM_17
xtreg Market_capitalization `x' lnY RealGDPgr inflation, vce(robust)
outreg2 using "$path\tables\Market_capitalization_vs2.xls", append
xtreg Domestic_credit `x' lnY RealGDPgr inflation, vce(robust)
outreg2 using "$path\tables\Domestic_credit_vs2.xls", append
xtreg `x' Market_capitalization Domestic_credit lnY RealGDPgr inflation, vce(robust)
outreg2 using "$path\tables\iMaPP_DC_MC_vs2.xls", append
}
foreach x of varlist Market_capitalization Domestic_credit lnY C_SUM_17 C_Loan_Sum C_Supply_Sum C_LDemand_Sum C_LSupply_Sum C_Other_Sum C_Supply_capital C_Supply_general {
g `x'_1990 = `x'
g `x'_2019 = `x' // `x'_2016
}
sort Cid Year
drop if Year>2019
collapse (firstnm) *1990 (lastnm) *2019, by(Cid iso3 Country CountryName)  // Country_Type  //*2016
foreach x of local XY {
g dif_`x' = `x'_2019-`x'_1990  //`x'_2016
}
sum dif_Market_capitalization dif_Domestic_credit dif_C_SUM_17 if dif_C_SUM_17<.
label var dif_Market_capitalization "Change in market capitalization (% of GDP)"
label var dif_Domestic_credit "Change in domestic credit (% of GDP)"
label var dif_C_SUM_17 "Net macroprudential tightening until 2019"  // 2016
*graph twoway scatter dif_Market_capitalization dif_C_SUM_17, mlabel(iso3) saving(graph1, replace)
*graph twoway scatter dif_Domestic_credit dif_C_SUM_17, mlabel(iso3) saving(graph2, replace)
graph twoway scatter dif_Market_capitalization dif_C_SUM_17 if strpos(iso3, "CHL")==0, mlabel(iso3) ///   note("Chile is red dot")
 || scatter dif_Market_capitalization dif_C_SUM_17 if strpos(iso3, "CHL"), legend(off span forcesize) mlabel(Country) mcolor(red) saving(graph1, replace)
graph twoway scatter dif_Domestic_credit dif_C_SUM_17 if strpos(iso3, "CHL")==0, mlabel(iso3) /// note("Chile is red dot")
 || scatter dif_Domestic_credit dif_C_SUM_17 if strpos(iso3, "CHL"), legend(off span forcesize) mlabel(Country) mcolor(red) saving(graph2, replace)
graph combine graph1.gph graph2.gph, `G2' 
graph export "$path\EMF\iMaPP_MC_DC_1990_2016.emf", replace
graph export "$pathgE\\iMaPP_MC_DC_1990_2016.emf", replace
graph export "$pathgT\\iMaPP_MC_DC_1990_2016.tif", replace
cd "C:\Docs2\EFH_CDI\Chile_MaPP_comparison\\Gráficos finales\Gráficos inglés\TIFF\"
graph export iMaPP_MC_DC_1990_2016.tiff, as(tif) name("Graph") replace
