cd "C:\Docs2\EFH_CDI\Chile_MaPP_comparison\\"
use "C:\Docs2\EFH_CDI\Chile_MaPP_comparison\IMFdata\Pasricha.dta", clear
keep country wb_code region qdate year quarterly ifs_code netnkirestr hotnetnkirestr
rename ifs_code ifscode
rename wb_code iso3
collapse (sum) netnkirestr-hotnetnkirestr, by(country iso3 region year ifscode)
merge m:m ifscode using "C:\Docs2\EFH_CDI\Chile_MaPP_comparison\IMFdata\\CountryType.dta", keepusing(Country_Type)

**** Se limpia la base de datos para dejar solo lo que interesa
drop if _merge!=3
gen EM=1 if Country_Type==2
gen LIC=1 if Country_Type==3
drop _merge Country_Type
order netnkirestr,b(hotnetnkirestr)
gen totalnki=netnkirestr+hotnetnkirestr
order totalnki,a(hotnetnkirestr)

bysort country (year) : gen C_netnkirestr = sum(netnkirestr)
bysort country (year) : gen C_hotnetnkirestr = sum(hotnetnkirestr)
bysort country (year) : gen C_totalnki = sum(totalnki)

capture label var netnkirestr "No. of Net FDI NKI Restricting Measures"
capture label var hotnetnkirestr "No. of non-FDI Net NKI Restricting Measures"
capture label var totalnki "No. of Net NKI Restricting Measures"
capture label var C_netnkirestr "Cumulative no. of Net FDI NKI Restricting Measures"
capture label var C_hotnetnkirestr "Cumulative no. of non-FDI Net NKI Restricting Measures"
capture label var C_totalnki "Cumulative no. of Net NKI Restricting Measures"

**** Se crean variables para los loops
local P_LA6 ARG BRA CHL COL MEX PER
local P_OECD AUS AUT BEL CAN CHL CZE DNK EST FIN FRA DEU GRC HUN ISL IRL ISR ITA JPN KOR LUX NLD NZL NOR POL PRT SVK SVN ESP SWE CHE GBR USA COL LVA LTU MEX TUR
local tipos LA6 OECD EM LIC
local variables netnkirestr-totalnki C_netnkirestr-C_totalnki
gen LA6=0
gen OECD=0

**** Se crean los promedios para cada agrupación de países (LAC, LAC_6, OCDE, EM y LIC)
foreach j of local tipos{
	foreach y of local P_`j'{
		replace `j'=1 if iso3=="`y'"
	}

	foreach y of varlist netnkirestr-totalnki C_netnkirestr-C_totalnki{
		bys year: egen mean_`y'=${StatV}(`y') if `j'==1 & strpos(iso3, "m_")==0
	}
	if "`j'"=="LIC" {
	expand 2 if iso3=="IND", gen(duplicate)
	foreach y of varlist netnkirestr-totalnki C_netnkirestr-C_totalnki{
		replace `y'=mean_`y' if duplicate==1
	}	
	}
	else{
	expand 2 if iso3=="CHL", gen(duplicate)
	foreach y of varlist netnkirestr-totalnki C_netnkirestr-C_totalnki{
		replace `y'=mean_`y' if duplicate==1
	}
	}
	
	replace country="Promedio `j'" if duplicate==1
	replace iso3="m_`j'" if duplicate==1
	drop mean_netnkirestr-duplicate
}
sort country year

**** En esta sección se colocan los códigos iso3 de los países que se desean analizar en cada agrupación (mientras más se coloquen peor se verán los gráficos)
keep if iso3=="CHL"|strpos(iso3, "m_")
egen cgroup=group(country)
xtset cgroup year, yearly
foreach j of local variables{
	preserve
	foreach y of varlist `j'{
		xtline `y', overlay ytitle(Index, size(small)) ylabel(, labsize(small)) title("",size(zero)) legend(cols(3) size(vsmall) order(1 "Chile" 2 "${StatT} EM" 3 "${StatT} LA6" 4 "${StatT} LIC" 5 "${StatT} OECD")) ttitle(, size(zero)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
		cd "C:\Docs2\EFH_CDI\Chile_MaPP_comparison\\Gráficos finales\Gráficos inglés\TIFF\"
		graph export `y'_serie.tiff, as(tif) name("Graph") replace   // `y'_Pasricha_serie.tiff
		cd "C:\Docs2\EFH_CDI\Chile_MaPP_comparison\\Gráficos finales\Gráficos inglés\EMF\"
		graph export `y'_serie.emf, as(emf) name("Graph") replace   // `y'_Pasricha_serie.emf
	}
	restore
}
