global path_p "C:\Docs2\EFH_CDI\Chile_MaPP_comparison\IMFdata\iMaPP_new\" // replace ./
local Mvarlist "*SUM* *Loan_Sum* *LDemand_Sum* *LSupply_Sum* *Supply_general* *Supply_capital* *Supply_Sum* *Other_Sum*" // Reduced varlist
local Mv2 "LTV DSTI LoanR LCG LLP Capital Tax"
local C_Mv2 "C_LTV C_DSTI C_LoanR C_LCG C_LLP C_Capital C_Tax"
local C3_Mv2 "C3_LTV C3_DSTI C3_LoanR C3_LCG C3_LLP C3_Capital C3_Tax"
local Cl_Mv2 "Cl_LTV Cl_DSTI Cl_LoanR Cl_LCG Cl_LLP Cl_Capital Cl_Tax"
local Mvarlist "`Mvarlist' `Mv2' `C_Mv2' `C3_Mv2' `Cl_Mv2'"

use "$path_p/iMaPP_Q.dta", clear   // List of variables to be included in the Yearly data
	// Time aggregation
//“Loan-targeted” group consists of the “Demand” and the “Supply-loans” instruments. 
// “Demand” instruments are the limits to the loan-to-value ratio (LTV) and the limits to the debt-service-to-income (DSTI) ratio. 
// “Supply-loans” measures are limits to credit growth (LCG), loan loss provisions (LLP), loan restrictions (LoanR), 
// limits to the loan to deposit ratio, and limits to foreign currency loans. 
//“Supply-general” instruments are reserve requirements, liquidity requirements, and limits to FX positions. 
//“Supply-capital” instruments are leverage limits (LVR), countercyclical buffers (CCB), conservation buffers, and capital requirements.
g LDemand_Sum=LTV+DSTI
g LSupply_Sum=LCG+LLP+LoanR+LTD+LFC
g Loan_Sum=LDemand_Sum+LSupply_Sum
g Supply_general=RR+Liquidity+LFX
g Supply_capital=LVR+CCB+Conservation+Capital
g Supply_Sum=Supply_general+Supply_capital  //g Sum_17_tes=Loan_Sum+Supply_Sum+Tax+SIFI+OT // sum SUM Sum_17 // pwcorr SUM Sum_17 //(Same! great)
g Other_Sum=Tax+SIFI+OT
g Supply_Sum2=Supply_Sum+Other_Sum

local varlist CCB Conservation Capital Capital_Gen Capital_HH Capital_Corp Capital_FX ///
		  LVR LLP LCG LCG_Gen LCG_HH LCG_Corp LoanR LoanR_HH LoanR_Corp LFC ///
		  LTV DSTI Tax Liquidity LTD LFX RR RR_FCD SIFI OT SUM_17 ///
		  Loan_Sum LDemand_Sum LSupply_Sum Supply_general Supply_capital Supply_Sum Other_Sum Supply_Sum2
g LTV_mean = LTV_Qmean 	
g LTV_level = LTV_Qmax
drop LTV_Qmean-LTV_Qmax_med
	collapse (sum) CCB-Supply_Sum2 (mean) LTV_mean (max) LTV_level, by(Year Country ifscode iso2 iso3 AE EMDE)  // `varlist'
egen country_nr=group(Country)	
xtset country_nr Year 
sum Year
local y0=r(min)	
local y1=`y0'+1	
local y2=r(max)	
quietly { 
foreach var of varlist CCB-Supply_Sum2 { //`varlist'
g C_`var'=`var' if Year==`y0'
forv dd=`y1'/`y2' {
g var0=L.C_`var' 
replace C_`var'=var0+`var' if Year==`dd' & `var'<.      //replace C_`var'=`var' if C_`var'==. & Year==`dd' //replace C_`var'=0 if C_`var'==. & Year==`dd'
drop var0
}
g Cl_`var'=L.C_`var'  //replace Cl_`var'=0 if Cl_`var'==. & C_`var'<.
}
}	
run "$path_p/iMaPP_labels.do" 	// Data labels
	sort ifscode Year
	format %ty Year
save "$path_p/iMaPP_Y.dta", replace  //keep `Mvarlist' *LTV* Year Country co* ifscode iso2 iso3 AE EMDE
save "$path_p/iMaPP_Yred.dta", replace

use "$path_p/iMaPP_Q.dta", clear   // List of variables to be included in the Yearly data
g LDemand_Sum=LTV+DSTI
g LSupply_Sum=LCG+LLP+LoanR+LTD+LFC
g Loan_Sum=LDemand_Sum+LSupply_Sum
g Supply_general=RR+Liquidity+LFX
g Supply_capital=LVR+CCB+Conservation+Capital
g Supply_Sum=Supply_general+Supply_capital 
g Other_Sum=Tax+SIFI+OT
g Supply_Sum2=Supply_Sum+Other_Sum
g LTV_mean = LTV_Qmean 	
g LTV_level = LTV_Qmax
	collapse (max) CCB-Supply_Sum2 (max) LTV_mean (max) LTV_level, by(Year Country ifscode iso2 iso3 AE EMDE)  //`varlist'
joinby Year Country ifscode iso2 iso3 AE EMDE using "$path_p/iMaPP_Y.dta", unmatched(both) update
tab _merge
drop _merge	
run "$path_p/iMaPP_labels.do" 	// Data labels
	sort ifscode Year
	format %ty Year
save "$path_p/iMaPP_Y2.dta", replace

foreach file1 in iMaPP_Y iMaPP_Y2 iMaPP_Q iMaPP_M {
use "$path_p\`file1'.dta", clear
tab Country if ifs==.  // Curacao is developed (36,000 USD in GDPpc)
replace AE=1 if ifs==.
replace EMDE=0 if ifs==.
tab Country if iso2==""
replace iso2="CW" if iso2=="" 
replace iso3="CUW" if iso3==""
save "$path_p\`file1'.dta", replace
}
use "$path_p\iMaPP_Y.dta", clear
collapse ifscode, by(iso3 iso2)
drop if ifscode==.
save "$path_p\IMFcodes.dta", replace

use "$path_p/iMaPP_Y.dta", clear
drop Cl*  // C2* C3* C4*
*drop C_Supply_general C_Supply_capital C_Supply_Sum2
save "$path_p/iMaPP_Y_otherVars.dta", replace
